@@ -313,6 +313,7 @@ typedef struct module_t
   int                   fd;
   int                   active;
   char                 *name;
+  char                 *cmd_line;
   CARD32                mask;
   CARD32                lock_on_send_mask;
   queue_buff_struct    *output_queue;
@@ -458,7 +459,7 @@ void on_window_pressure_changed( ASWindow *asw, int pressed_context );
 
 void SelectDecor (ASWindow *);
 void check_aswindow_shaped( ASWindow *asw );
-ASWindow *AddWindow (Window w);
+ASWindow *AddWindow (Window w, Bool from_map_request);
 ASWindow *AddInternalWindow (Window w,
                              ASInternalWindow **pinternal,
                              struct ASHints **phints, struct ASStatusHints *status);
@@ -521,6 +522,7 @@ ASFlagType compile_titlebuttons_mask (ASHints *hints);
 void estimate_titlebar_size( ASHints *hints, unsigned int *width_ret, unsigned int *height_ret );
 void disable_titlebuttons_with_function (ASWindow * t, int function);
 Bool hints2decorations( ASWindow *asw, ASHints *old_hints );
+void invalidate_window_mystyles( ASWindow *asw );
 
 /*************************** events.c ********************************/
 const char *context2text(int ctx);
@@ -645,13 +647,20 @@ void broadcast_config (send_data_type event_type, ASWindow * t);
 void HandleModuleInOut(unsigned int channel, Bool has_input, Bool has_output);
 
 void KillModuleByName (char *name);
+void KillAllModulesByName (char *name);
+
 int FindModuleByName (char *name);
+char *GetModuleCmdLineByName(char *name);
 void DeadPipe (int nonsense);
 void ShutdownModules(Bool dont_free_memory);
 
 void RunCommand (FunctionData * fdata, unsigned int channel, Window w);
 
 void FlushAllQueues();
+MenuData *make_module_menu( FunctionCode func, const char *title, int sort_order );
+#define make_stop_module_menu(sort_order)  make_module_menu(  F_KILLMODULEBYNAME, "Stop Running Module", sort_order )
+#define make_restart_module_menu(sort_order)  make_module_menu(  F_RESTARTMODULEBYNAME, "Restart Running Module", sort_order )
+
 
 /******************************* outline.c ********************************/
 void MoveOutline( struct MoveResizeData * pdata );
@@ -691,7 +700,7 @@ Bool install_theme_file( const char *src );
 /******************************* winstatus.c *******************************/
 void complete_wm_state_transition( ASWindow *asw, int state );
 Bool apply_window_status_size(register ASWindow *asw, ASOrientation *od);
-Bool set_window_wm_state( ASWindow *asw, Bool iconify );
+Bool set_window_wm_state( ASWindow *asw, Bool iconify, Bool force_unmapped );
 Bool make_aswindow_visible( ASWindow *asw, Bool deiconify );
 void change_aswindow_layer( ASWindow *asw, int layer );
 void quietly_reparent_aswindow( ASWindow *asw, Window dst, Bool user_root_pos );
